# Left Pad

just add left padding to the text.

## Installation

Run the following to install:

```python
pip install left-pad
```

## Usage

```python

from left_pad import left_pad

left_pad('This is awesome string', length=40, character='*')

# ********This is awesome string

```


